yaqd-control

# yaq-control

Command line tools for inspecting and controlling yaq daemons.

## installation

yaqd-control can be installed via PyPI or conda-forge.

    $ pip install yaqd-control

    $ conda config --add channels conda-forge
    $ conda install yaqd-control

## usage

yaqd-control is a command line application. This quickstart will introduce the basic features of yaqd-control for a simple imaginary system.

Scanning: yaqd-control must find the daemons before interacting with them.

    $ yaqd scan
    TODO: fake output

Status: yaqd-control can quickly show you the status of all installed daemons.

    $ yaqd status
    TODO: fake output

Enablement: by enabling a daemon, you allow the operating system to manage that daemon in the background. An enabled daemon will always start again when you restart your computer. After enabling, it's typical to start the daemon as well.

    $ yaqd enable system-monitor
    TODO: fake output

Help: learn more, right from your terminal.

    $ yaqd --help
    Usage: yaqd [OPTIONS] COMMAND [ARGS]...

    Options:
      --help  Show this message and exit.

    Commands:
      clear-cache
      disable
      edit-config
      enable
      list
      reload
      restart
      scan
      start
      status
      stop

Try `yaqd --help` to learn more about a particular command.

CC0: no copyright